@@ -4,13 +4,14 @@
 #' area under a survival curve (over age) with the area under a constant
 #' survival function.
 #'
-#' @param surv Either 1) a numeric vector describing a survival curve (lx), or
-#'   2) a \code{data.frame} / \code{list} with one column / element titled 'lx'
+#' @param surv Either 1) a numeric vector describing a survival curve (lx), 2) a
+#'   \code{data.frame} / \code{list} with one column / element titled 'lx'
 #'   describing a survival curve, optionally a column / element 'x' containing
 #'   age classes (each element a number representing the age at the start of the
-#'   class).
+#'   class), or 3), a \code{matrix}, specifically the U submatrix of a matrix
+#'   population model (A).
 #'
-#'   If \code{x} is not supplied, the function will assume age classes starting
+#'   In case (2) If \code{x} is not supplied, the function will assume age classes starting
 #'   at \code{0} with time steps of \code{1} unit of the
 #'   \code{ProjectionInterval}. If \code{x} begins at \code{0} then \code{lx[1]}
 #'   should equal \code{1}. If \code{x} ends at maximum longevity, then
@@ -26,7 +27,8 @@
 #'   be handled. \code{trunc == TRUE} strips out the zero value(s). An
 #'   alternative to this is to transform the zeroes to something approximating
 #'   zero (e.g., 1e-7).
-#'
+#' @param ... Additional variables passed to `mpm_to_lx`, if data are supplied
+#'   as a matrix.
 #' @return a shape value describing lifespan inequality by comparing the area
 #'   under a survival (\code{lx}) curve over age with the area under a constant
 #'   (Type II) survival function. The shape value may take any real value
@@ -47,8 +49,18 @@
 #' lx <- 0.7^(0:20)
 #' shape_surv(lx)
 #'
+#' data(mpm1)
+#' shape_surv(mpm1$matU)
+#'
+#' lx <- mpm_to_lx(mpm1$matU, start = 1)
+#' shape_surv(lx)
+#'
 #' @export shape_surv
-shape_surv <- function(surv, xmin = NULL, xmax = NULL, trunc = FALSE) {
+shape_surv <- function(surv, xmin = NULL, xmax = NULL, trunc = FALSE, ...) {
+  if (inherits(surv, "matrix")) {
+    surv <- mpm_to_lx(surv, ...)
+  }
+
   if (class(surv) %in% "numeric") {
     lx <- surv
     x <- seq_along(lx) - 1
